PyDREAM
-------

A Python implementation of the MT-DREAM(ZS) algorithm presented in `Laloy and Vrugt 2012 <http://faculty.sites.uci.edu/jasper/files/2016/04/72.pdf>`_.

For example usage, see the examples folder.  Two of the examples, CORM and Robertson, require the Python modeling framework `PySB <https://github.com/LoLab-VU/pysb>`_.

Documentation is available at `Read the Docs <http://pydream.readthedocs.io>`_.